# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.1] - 2024-12-24
### Added
- `--v-shift` and `--h-shift` arguments
- `--timezone` argument
- `--face` argument
- `run_clock` and `main` functions
- `TIMEZONES.md`
- `FACES.md`

[Unreleased]: https://github.com/sepandhaghighi/clox/compare/v0.1...dev
[0.1]: https://github.com/sepandhaghighi/clox/compare/e9b49e2...v0.1



